====
zfit
====


.. image:: https://img.shields.io/pypi/v/zfit.svg
        :target: https://pypi.python.org/pypi/zfit

.. image:: https://img.shields.io/travis/zfit/zfit.svg
        :target: https://travis-ci.org/zfit/zfit

.. image:: https://readthedocs.org/projects/zfit/badge/?version=latest
        :target: https://zfit.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status
.. image:: https://coveralls.io/repos/github/zfit/zfit/badge.svg?branch=meta_changes
        :target: https://coveralls.io/github/zfit/zfit?branch=meta_changes
.. image:: https://www.codefactor.io/repository/github/zfit/zfit/badge
   :target: https://www.codefactor.io/repository/github/zfit/zfit
   :alt: CodeFactor


* Free software: BSD-3-Clause
* `Full Documentation <https://zfit.github.io/zfit/>`_

The ``zfit`` package provides scalable, pythonic fitting. It is currently in it's beta stage: core parts are
established, but it's not feature complete. It can (and is) used in analysis.


Acknowledgements
----------------

zfit has been developed with support from the University of Zürich and the Swiss National Science Foundation (SNF) under contracts 168169 and 174182.

The authors would like to thank numerous invaluable inputs and inspiration from other packages and
the HSF community.
